@@ -33,9 +33,7 @@
 					   stdlib.h (EKU) */
 #endif
 #include "vector.h"
-#ifndef __GNUC__
 #include <new>
-#endif
 
 // This macro controls merging of nodes of all B+ trees
 // Now it merges pages only when resulting page will be 3/4 filled or less
@@ -215,7 +213,7 @@ public:
 	}
     Value& current() const { return (*curr)[curPos]; }
 	Value& getAddErrorValue() { return addErrorValue; }
-    int getCount() const { return count; }
+    int getCount() const { return this->count; }
 private:
 	BePlusTree(Allocator *_pool, void *rootPage) : 	pool(_pool), level(0), 
 		curr(new(rootPage) ItemList()), root(rootPage),	curPos(0)/*, count(0)*/  {};
@@ -257,10 +255,10 @@ private:
 		int level;
 		NodeList *parent;
 		NodeList *next, *prev;
-		static const Key& generate(void *sender, void *item) { 
+		static const Key& generate(const void *sender, void *item) { 
 			for (int lev = ((NodeList *)sender)->level; lev > 0; lev--)
 				item = *((NodeList *)item)->begin();
-			return KeyOfValue::generate(item,*((BePlusTree::ItemList *)item)->begin());
+			return KeyOfValue::generate(item,*((ItemList *)item)->begin());
 		}
 		static void setNodeParentAndLevel(void *node, int level, NodeList *parent) {
 			if (level) {
