@@ -41,12 +41,11 @@
 #include "../jrd/y_ref.h"
 
 //! Dynamic SQL Error Status Block
-struct err
+struct dsql_err_stblock
 {
 	ISC_STATUS* dsql_status;
 	ISC_STATUS* dsql_user_status;
 };
-typedef err* ERR;
 
 
 // this table is used in data allocation to determine
@@ -430,7 +429,7 @@ public:
 	ULONG	req_updates;
 	ULONG	req_selects;
 	REQ_TYPE req_type;			//!< Type of request
-	USHORT	req_base_offset;		//!< place to go back and stuff in blr length
+	ULONG	req_base_offset;	//!< place to go back and stuff in blr length
 	USHORT	req_context_number;	//!< Next available context number
 	USHORT	req_scope_level;		//!< Scope level for parsing aliases in subqueries
 	USHORT	req_message_number;	//!< Next available message number
