@@ -29,7 +29,7 @@
  * 2002.10.29 Nickolay Samofatov: Added support for savepoints
  */
 /*
-$Id: gen.cpp,v 1.33.2.3 2003/12/21 00:43:47 skidder Exp $
+$Id: gen.cpp,v 1.33.2.5 2005/09/30 13:13:45 paul_reeves Exp $
 */
 
 #include "firebird.h"
@@ -51,6 +51,7 @@ $Id: gen.cpp,v 1.33.2.3 2003/12/21 00:43:47 skidder Exp $
 #include "../jrd/thd_proto.h"
 #include "../jrd/dsc_proto.h"
 #include "gen/iberror.h"
+#include "../common/config/config.h"
 
 ASSERT_FILENAME static void gen_aggregate(DSQL_REQ, DSQL_NOD);
 static void gen_cast(DSQL_REQ, DSQL_NOD);
@@ -1248,8 +1249,8 @@ static void gen_cast( DSQL_REQ request, DSQL_NOD node)
 	blr for expression 1
 		blr_value_if
 		blr_missing
-		blr for expression n
-		blr_null
+		blr for expression n-1
+		expression n
 	blr for expression n-1
 
     @param request
@@ -1264,7 +1265,7 @@ static void gen_coalesce( DSQL_REQ request, DSQL_NOD node)
 	list = node->nod_arg[0];
 	STUFF(blr_cast);
 	gen_descriptor(request, &node->nod_desc, TRUE);
-	for (ptr = list->nod_arg, end = ptr + list->nod_count; ptr < end; ptr++)
+	for (ptr = list->nod_arg, end = ptr + (list->nod_count - 1); ptr < end; ptr++)
 	{
 		// IF (expression IS NULL) THEN
 		STUFF(blr_value_if);
@@ -1276,7 +1277,6 @@ static void gen_coalesce( DSQL_REQ request, DSQL_NOD node)
 	end = list->nod_arg;
 	ptr = end + list->nod_count;
 	// if all expressions are NULL return NULL
-	STUFF(blr_null);
 	for (ptr--; ptr >= end; ptr--)
 	{
 		GEN_expr(request, *ptr);
@@ -2318,20 +2318,30 @@ static void gen_select( DSQL_REQ request, DSQL_NOD rse)
               FIXED IN PARSE.Y; here it doesn't catch expressions: Bug 450301. */
             parameter->par_name = parameter->par_alias  = "SUBSTRING";
         }
-        else if (item->nod_type == nod_concatenate)
-            parameter->par_name = parameter->par_alias	= "CONCATENATION";
+        else if (item->nod_type == nod_concatenate) {
+            if ( !Config::getOldColumnNaming() ) 
+                parameter->par_name = parameter->par_alias  = "CONCATENATION";
+        }
         else if (item->nod_type == nod_cast)
-            parameter->par_name = parameter->par_alias	= "CAST";
+            parameter->par_name = parameter->par_alias  = "CAST";
         else if (item->nod_type == nod_upcase)
-            parameter->par_name = parameter->par_alias	= "UPPER";
-        else if (item->nod_type == nod_current_date)
-            parameter->par_name = parameter->par_alias	= "CURRENT_DATE";
-        else if (item->nod_type == nod_current_time)
-            parameter->par_name = parameter->par_alias	= "CURRENT_TIME";
-        else if (item->nod_type == nod_current_timestamp)
-            parameter->par_name = parameter->par_alias	= "CURRENT_TIMESTAMP";
-        else if (item->nod_type == nod_extract)
-            parameter->par_name = parameter->par_alias	= "EXTRACT";
+            parameter->par_name = parameter->par_alias  = "UPPER";
+        else if (item->nod_type == nod_current_date) {
+            if ( !Config::getOldColumnNaming() ) 
+                parameter->par_name = parameter->par_alias  = "CURRENT_DATE";
+        }
+        else if (item->nod_type == nod_current_time) {
+            if ( !Config::getOldColumnNaming() ) 
+                parameter->par_name = parameter->par_alias  = "CURRENT_TIME";
+        }
+        else if (item->nod_type == nod_current_timestamp) {
+            if ( !Config::getOldColumnNaming() ) 
+                parameter->par_name = parameter->par_alias  = "CURRENT_TIMESTAMP";
+        }
+        else if (item->nod_type == nod_extract) {
+            if ( !Config::getOldColumnNaming() ) 
+                parameter->par_name = parameter->par_alias  = "EXTRACT";
+        }
         else if (item->nod_type == nod_searched_case)
             parameter->par_name = parameter->par_alias	= "CASE";
         else if (item->nod_type == nod_simple_case)
