@@ -25,7 +25,7 @@
 //
 //____________________________________________________________
 //
-//	$Id: cmp.cpp,v 1.12 2003/02/27 16:05:13 brodsom Exp $
+//	$Id: cmp.cpp,v 1.12.2.1 2005/10/24 16:51:46 awharrison Exp $
 //
 
 #include "firebird.h"
@@ -85,7 +85,7 @@ static void update_references(REF);
 
 static GPRE_NOD lit0, lit1;
 static GPRE_FLD eof_field, count_field, slack_byte_field;
-static USHORT next_ident;
+static ULONG next_ident;
 
 #define STUFF(blr)	*request->req_blr++ = (UCHAR)(blr)
 #define STUFF_WORD(blr) {STUFF (blr); STUFF ((blr) >> 8);}
@@ -430,7 +430,7 @@ void CMP_init(void)
 //		Give out next identifier.
 //  
 
-USHORT CMP_next_ident(void)
+ULONG CMP_next_ident(void)
 {
 
 	return next_ident++;
