@@ -153,10 +153,10 @@ void IDX_check_access(TDBB tdbb, CSB csb, JRD_REL view, JRD_REL relation, JRD_FL
 				CMP_post_access(tdbb, csb,
 								referenced_relation->rel_security_name, 
 									(view ? view->rel_id : 0),
-								0, 0, SCL_sql_references, "TABLE",
+								SCL_sql_references, "TABLE",
 								referenced_relation->rel_name);
 				CMP_post_access(tdbb, csb,
-								referenced_field->fld_security_name, 0, 0, 0,
+								referenced_field->fld_security_name, 0,
 								SCL_sql_references, "COLUMN",
 								referenced_field->fld_name);
 			}
@@ -207,6 +207,10 @@ void IDX_create_index(
 		ERR_post(gds_no_meta_update, gds_arg_gds, gds_extfile_uns_op,
 				 gds_arg_string, ERR_cstring(relation->rel_name), 0);
 
+	if (!relation->rel_index_root) {
+		get_root_page(tdbb, relation);
+	}
+
 	BTR_reserve_slot(tdbb, relation, transaction, idx);
 
 	if (index_id) {
@@ -1142,13 +1146,13 @@ JRD_REL partner_relation, SSHORT index_id)
 		retrieval.irb_generic = irb_equality;
 		retrieval.irb_relation = partner_relation;
 		retrieval.irb_key = &key;
+		retrieval.irb_upper_count = retrieval.irb_lower_count = idx->idx_count;
 		if (partner_idx.idx_flags & idx_descending) {
 			retrieval.irb_generic |= irb_descending;
-			retrieval.irb_upper_count = retrieval.irb_lower_count = 0;
 		}
-		else {
-			retrieval.irb_upper_count = 
-				retrieval.irb_lower_count = idx->idx_count;
+		if ((partner_idx.idx_flags & idx_descending) != 
+					(idx->idx_flags & idx_descending)) {
+			BTR_complement_key(&key);
 		}
 		BTR_evaluate(tdbb, &retrieval, &bitmap);
 
