@@ -34,7 +34,7 @@
  *
  */
 
- /* $Id: isc_ipc.cpp,v 1.37 2003/04/10 06:49:12 aafemt Exp $ */
+ /* $Id: isc_ipc.cpp,v 1.37.2.1 2005/09/21 07:51:09 alexpeshkoff Exp $ */
 
 #ifdef SHLIB_DEFS
 #define LOCAL_SHLIB_DEFS
@@ -483,8 +483,15 @@ int ISC_kill(SLONG pid, SLONG signal_number)
 
 	if (!relay_pipe) {
 		gds__prefix(process, GDS_RELAY);
+		if (access(process, X_OK) != 0) {
+			// we don't have relay, therefore simply give meaningful diagnostic
+			gds__log("ISC_kill: process %d couldn't deliver signal %d "
+				"to process %d: permission denied", getpid(), signal_number, pid);
+			return -1;
+		}
+
 		if (pipe(pipes)) {
-			gds__log("ISC_kill: error %d creating gds_relay", errno);
+			gds__log("ISC_kill: error %d creating pipe to gds_relay", errno);
 			return -1;
 		}
 		sprintf(arg, "%d", pipes[0]);
