@@ -516,6 +516,7 @@ typedef jrd_prc* JRD_PRC;
 #define PRC_blocking          16	/* Blocking someone from dropping procedure */
 #define PRC_create            32	/* Newly created */
 #define PRC_being_altered     64	/* Procedure is getting altered */
+#define PRC_check_existence   128	/* Existence lock released */
 
 #define MAX_PROC_ALTER        64	/* No. of times an in-cache procedure can be altered */
 
@@ -854,7 +855,7 @@ class btb : public pool_alloc<type_btb>
 {
     public:
 	btb *btb_next;
-	SLONG btb_thread_id;
+	struct thread* btb_thread_id;
 };
 typedef btb *BTB;
 
@@ -889,7 +890,7 @@ typedef btb *BTB;
 typedef struct win {
 	SLONG win_page;
 	struct pag *win_buffer;
-	struct exp *win_expanded_buffer;
+	struct exp_index_buf *win_expanded_buffer;
 	struct bdb *win_bdb;
 	SSHORT win_scans;
 	USHORT win_flags;
