@@ -55,7 +55,7 @@ typedef struct thread {
 	struct thread *thread_next;	/* Next thread to be scheduled */
 	struct thread *thread_prior;	/* Prior thread */
 	EVENT_T thread_stall[1];	/* Generic event to stall thread */
-	SLONG thread_id;			/* Current thread id */
+	FB_THREAD_ID thread_id;			/* Current thread id */
 	USHORT thread_count;		/* AST disable count */
 	USHORT thread_flags;		/* Flags */
 } *THREAD;
@@ -213,7 +213,7 @@ void SCH_abort(void)
  *
  **************************************/
 	THREAD *ptr, thread;
-	SLONG id;
+	FB_THREAD_ID id;
 	int mutex_state;
 
 /* If threading isn't active, don't sweat it */
@@ -486,7 +486,11 @@ void SCH_exit(void)
 	// happens during attach to database in SS builds. Exception
 	// handler there calls THREAD_EXIT without preceding THREAD_ENTER
 	// in this case (during shutdown of CACHE_WRITER or CACHE_READER)
-	if (!thread) return; 
+	if (!thread) {
+		if (mutex_state = THD_mutex_unlock(thread_mutex))
+			mutex_bugcheck("mutex unlock", mutex_state);
+		return;
+	}
 
 	if (thread == thread->thread_next)
 		active_thread = NULL;
